@@ -15,9 +15,9 @@ from cms.contexts.decorators import detect_language
 from cms.contexts.utils import clone
 from cms.menus.forms import MenuForm
 from cms.menus.models import NavigationBar
-from cms.menus.serializers import MenuSerializer
+from cms.menus.serializers import MenuSelectOptionsSerializer, MenuSerializer
 
-from . generics import UniCMSCachedRetrieveUpdateDestroyAPIView, UniCMSListCreateAPIView
+from . generics import *
 from . logs import ObjectLogEntriesList
 from .. exceptions import LoggedPermissionDenied, LoggedValidationException
 from .. permissions import MenuGetCreatePermissions
@@ -203,9 +203,39 @@ class MenuCloneView(APIView):
                              custom_values={'name': f'{item.name} (copy {timezone.localtime()})'},
                              recursive_custom_values={'created_by': request.user,
                                                       'modified_by': None})
-        except Exception as e:
+        except Exception as e: # pragma: no cover
             raise LoggedValidationException(classname=self.__class__.__name__,
                                             resource=request.method,
                                             detail=e)
         result = self.serializer_class(new_menu)
         return Response(result.data)
+
+
+class EditorialBoardMenuOptionListSchema(AutoSchema):
+    def get_operation_id(self, path, method):# pragma: no cover
+        return 'listMenuSelectOptions'
+
+
+class MenuOptionList(UniCMSListSelectOptionsAPIView):
+    """
+    """
+    description = ""
+    search_fields = ['name']
+    serializer_class = MenuSelectOptionsSerializer
+    queryset = NavigationBar.objects.all()
+    schema = EditorialBoardMenuOptionListSchema()
+
+
+class MenuOptionView(generics.RetrieveAPIView):
+    """
+    """
+    description = ""
+    permission_classes = [IsAdminUser]
+    serializer_class = MenuSelectOptionsSerializer
+
+    def get_queryset(self):
+        """
+        """
+        menu_id = self.kwargs['pk']
+        menu = NavigationBar.objects.filter(pk=menu_id)
+        return menu
