@@ -3,7 +3,12 @@ from django.urls import reverse
 
 from cms.api.settings import FORM_SOURCE_LABEL
 
-from . models import Publication, PublicationAttachment, PublicationGallery, PublicationLink, PublicationLocalization, PublicationRelated
+from . models import (Publication,
+                      PublicationAttachment,
+                      PublicationMediaCollection,
+                      PublicationLink,
+                      PublicationLocalization,
+                      PublicationRelated)
 
 
 class PublicationForm(ModelForm):
@@ -12,7 +17,8 @@ class PublicationForm(ModelForm):
         super().__init__(*args, **kwargs)
         setattr(self.fields['presentation_image'],
                 FORM_SOURCE_LABEL,
-                reverse('unicms_api:media-options'))
+                # only images
+                reverse('unicms_api:media-options') + '?file_type=image%2Fwebp')
 
     class Meta:
         model = Publication
@@ -35,16 +41,19 @@ class PublicationAttachmentForm(ModelForm):
                   'order', 'is_active']
 
 
-class PublicationGalleryForm(ModelForm):
+class PublicationMediaCollectionForm(ModelForm):
 
     def __init__(self, *args, **kwargs):
         publication_id = kwargs.pop('publication_id', None)
         super().__init__(*args, **kwargs)
         if publication_id:
             self.fields['publication'].queryset = Publication.objects.filter(pk=publication_id)
+        setattr(self.fields['collection'],
+                FORM_SOURCE_LABEL,
+                reverse('unicms_api:media-collection-options'))
 
     class Meta:
-        model = PublicationGallery
+        model = PublicationMediaCollection
         fields = ['publication', 'collection', 'order', 'is_active']
 
 
